@@ -4,7 +4,7 @@ License - MIT
 """
 
 import sys
-import nanosurf.lib.datatypes.prop_val as prop_val
+import nanosurf as nsf
 
 from app import app_base
 from modules.scan_module import module as scan_func
@@ -16,7 +16,7 @@ MyAppNameLong = "Nanosurf Python Imaging and Library Demo"
 
 class MyAppSettings(app_base.AppSettings):
     """ Settings defined here as PropVal are stored persistently in a ini-file"""
-    AppHelloMsg = prop_val.PropVal("Welcome to scan and library usage demo.")
+    AppHelloMsg = nsf.PropVal("Welcome to scan and library usage demo.")
     
 class MyApp(app_base.ApplicationBase):
     def __init__(self, *args, **kwargs):
