@@ -2,27 +2,28 @@
 Copyright Nanosurf AG 2021
 License - MIT
 """
-from nanosurf.lib.datatypes import sci_stream
 import numpy as np
-import math
 from PySide2 import QtWidgets
-import nanosurf.lib.datatypes.sci_val as sci_val
-from nanosurf.lib.gui import nsf_sci_edit, nsf_tables, nsf_plots, bind_gui
-from nanosurf.lib.math import sci_math 
+import nanosurf as nsf
 from app import module_base
 from modules.scan_module import module, settings
 
-class ResultTableID(nsf_tables.TableEntryIDs):
+class ResultTableID(nsf.gui.TableEntryIDs):
     """ identifier id are used in a nsf_table widget"""
     Items = 0
     Marker_X = 1
     Marker_Y = 2
     Noise_Floor = 3
 
-""" some usefull list of allowed prefixes used by nsf_sci_edit widgets"""
-allowed_count_units = [sci_val.up.Prefix.base]
-allowed_time_units = [sci_val.up.Prefix.base, sci_val.up.Prefix.milli]
-allowed_meter_units = [sci_val.up.Prefix.milli, sci_val.up.Prefix.micro, sci_val.up.Prefix.nano]
+ComboChannelEntries = [
+    nsf.gui.NSFComboEntry(settings.ChannelD.Deflection,'Deflection'),
+    nsf.gui.NSFComboEntry(settings.ChannelD.Topography,'Topography'),
+]
+
+""" some useful list of allowed prefixes used by nsf_sci_edit widgets"""
+allowed_count_units = [nsf.sci_val.up.Prefix.base]
+allowed_time_units = [nsf.sci_val.up.Prefix.base, nsf.sci_val.up.Prefix.milli]
+allowed_meter_units = [nsf.sci_val.up.Prefix.milli, nsf.sci_val.up.Prefix.micro, nsf.sci_val.up.Prefix.nano]
 
 class ScanScreen(module_base.ModuleScreen):
     def __init__(self):
@@ -34,27 +35,26 @@ class ScanScreen(module_base.ModuleScreen):
 
         # left layout - main controls ------------------------------------------------------------
 
-        self.scival_image_size = nsf_sci_edit.NSFSciEdit("Image Size")
+        self.scival_image_size = nsf.gui.NSFSciEdit("Image Size")
         self.scival_image_size.set_allowed_prefix_ids(allowed_meter_units)
-        self.scival_image_size.set_prefix_id(sci_val.up.Prefix.micro)
+        self.scival_image_size.set_prefix_id(nsf.sci_val.up.Prefix.micro)
         self.scival_image_size.set_precision(2)
         self.scival_image_size.set_value_min_max(0.0, 1.0)
 
-        self.scival_time_per_line = nsf_sci_edit.NSFSciEdit("Time per Line")
+        self.scival_time_per_line = nsf.gui.NSFSciEdit("Time per Line")
         self.scival_time_per_line.set_allowed_prefix_ids(allowed_time_units)
-        self.scival_time_per_line.set_prefix_id(sci_val.up.Prefix.base)
+        self.scival_time_per_line.set_prefix_id(nsf.sci_val.up.Prefix.base)
         self.scival_time_per_line.set_precision(2)
         self.scival_time_per_line.set_value_min_max(0.01, 5.0)
 
-        self.scival_points = nsf_sci_edit.NSFSciEdit("Data points")
+        self.scival_points = nsf.gui.NSFSciEdit("Data points")
         self.scival_points.set_allowed_prefix_ids(allowed_count_units)
-        self.scival_points.set_prefix_id(sci_val.up.Prefix.base)
+        self.scival_points.set_prefix_id(nsf.sci_val.up.Prefix.base)
         self.scival_points.set_precision(0)
         self.scival_points.set_value_min_max(2, 8000)
         
-        self.label_channel_dir = QtWidgets.QLabel("Channel")
-        self.combo_channel_dir = QtWidgets.QComboBox()
-        self.combo_channel_dir.addItems(settings.ChannelNames)
+        self.label_channel_dir = QtWidgets.QLabel()
+        self.combo_channel_dir = nsf.gui.NSFComboBox(ComboChannelEntries,"Channel")
         
         self.button_start_stop = QtWidgets.QPushButton("Start")
 
@@ -68,15 +68,15 @@ class ScanScreen(module_base.ModuleScreen):
         self.layout_left.addWidget(self.button_start_stop)
 
         # mid layout - plots and result ---------------------------------------------------------
-        self.chart_plot = nsf_plots.NSFChart()
-        self.colormap_plot = nsf_plots.NSFColormap()
-        self.spec_plot = nsf_plots.NSFChart(logmodex=True, logmodey=True)
+        self.chart_plot = nsf.gui.NSFChart()
+        self.colormap_plot = nsf.gui.NSFColormap()
+        self.spec_plot = nsf.gui.NSFChart(logmodex=True, logmodey=True)
 
         self.check_show_histogram = QtWidgets.QCheckBox("Show Histogram")
         self.check_show_backward = QtWidgets.QCheckBox("Show Backward line")
-        self.check_show_power_spec = QtWidgets.QCheckBox("Show Power Spectrum")
+        self.check_show_power_spec = QtWidgets.QCheckBox("Show Spectral density")
         self.check_show_compressed_spec = QtWidgets.QCheckBox("Compress Spectrum")
-        self.tableResults = nsf_tables.NSFNameValueTable(ResultTableID)
+        self.tableResults = nsf.gui.NSFNameValueTable(ResultTableID)
         self.tableResults.define_entry(ResultTableID.Items,"Current line")
         self.tableResults.define_entry(ResultTableID.Marker_X,"Peak X")
         self.tableResults.define_entry(ResultTableID.Marker_Y,"Peak Y")
@@ -127,13 +127,13 @@ class ScanScreen(module_base.ModuleScreen):
         """ connect here all gui widgets to settings of the module or any other source"""
         
         # binding ProVal to widgets ensure that they are alway in sync 
-        bind_gui.connect_to_property(self.combo_channel_dir, self.module.settings.channel_id)
-        bind_gui.connect_to_property(self.scival_image_size, self.module.settings.image_size)
-        bind_gui.connect_to_property(self.scival_time_per_line, self.module.settings.time_per_line)
-        bind_gui.connect_to_property(self.scival_points, self.module.settings.points_per_line)
-        bind_gui.connect_to_property(self.check_show_backward, self.module.settings.show_backward)
-        bind_gui.connect_to_property(self.check_show_power_spec, self.module.settings.show_power_spec)
-        bind_gui.connect_to_property(self.check_show_compressed_spec, self.module.settings.show_compress_spec)
+        nsf.gui.connect_to_property(self.combo_channel_dir, self.module.settings.channel_id)
+        nsf.gui.connect_to_property(self.scival_image_size, self.module.settings.image_size)
+        nsf.gui.connect_to_property(self.scival_time_per_line, self.module.settings.time_per_line)
+        nsf.gui.connect_to_property(self.scival_points, self.module.settings.points_per_line)
+        nsf.gui.connect_to_property(self.check_show_backward, self.module.settings.show_backward)
+        nsf.gui.connect_to_property(self.check_show_power_spec, self.module.settings.show_power_spec)
+        nsf.gui.connect_to_property(self.check_show_compressed_spec, self.module.settings.show_compress_spec)
         
         self.check_show_histogram.stateChanged.connect(self._show_histogram_clicked)
         self.check_show_backward.stateChanged.connect(self._show_backward_clicked)
@@ -152,30 +152,32 @@ class ScanScreen(module_base.ModuleScreen):
         self.module.sig_data_invalid.connect(self.set_data_invalid)
 
     def init_plot(self):
-        self.colormap_plot.set_title(f"Scan image - {settings.ChannelNames[self.module.settings.channel_id.value]}")
-        self.colormap_plot.set_label(nsf_plots.NSFColormap.Axis.bottom, "X-Axis")
-        self.colormap_plot.set_unit(nsf_plots.NSFColormap.Axis.bottom, "m")
-        self.colormap_plot.set_label(nsf_plots.NSFColormap.Axis.left, "Y-Axis")
-        self.colormap_plot.set_unit(nsf_plots.NSFColormap.Axis.left, "m")  
-        self.colormap_plot.set_unit(nsf_plots.NSFColormap.Axis.z, "m")  
+        channel_name = self.combo_channel_dir.entry_name(self.module.settings.channel_id.value)
+
+        self.colormap_plot.set_title(f"Scan image - {channel_name}")
+        self.colormap_plot.set_label(nsf.gui.NSFColormap.Axis.bottom, "X-Axis")
+        self.colormap_plot.set_unit(nsf.gui.NSFColormap.Axis.bottom, "m")
+        self.colormap_plot.set_label(nsf.gui.NSFColormap.Axis.left, "Y-Axis")
+        self.colormap_plot.set_unit(nsf.gui.NSFColormap.Axis.left, "m")  
+        self.colormap_plot.set_unit(nsf.gui.NSFColormap.Axis.z, "m")  
 
         scan_line = np.linspace(0, self.module.settings.image_size.value, self.module.settings.points_per_line.value)
         self.colormap_plot.set_xy_range(scan_line, scan_line)
         self.colormap_plot.set_data_points(self.module.settings.points_per_line.value, self.module.settings.points_per_line.value)
 
-        self.chart_plot.set_title(f"Current line chart - {settings.ChannelNames[self.module.settings.channel_id.value]}")
-        self.chart_plot.set_label(nsf_plots.NSFChart.Axis.bottom, "X-Axis")
-        self.chart_plot.set_unit(nsf_plots.NSFChart.Axis.bottom, "m")
-        self.chart_plot.set_label(nsf_plots.NSFChart.Axis.left, "Data")
-        self.chart_plot.set_unit(nsf_plots.NSFChart.Axis.left, "m")  
+        self.chart_plot.set_title(f"Current line chart - {channel_name}")
+        self.chart_plot.set_label(nsf.gui.NSFChart.Axis.bottom, "X-Axis")
+        self.chart_plot.set_unit(nsf.gui.NSFChart.Axis.bottom, "m")
+        self.chart_plot.set_label(nsf.gui.NSFChart.Axis.left, "Data")
+        self.chart_plot.set_unit(nsf.gui.NSFChart.Axis.left, "m")  
         self.chart_plot.plot.setXRange(0, self.module.settings.image_size.value)
         self.chart_plot.clear_plots()
 
-        self.spec_plot.set_title(f"Spectrum of - {settings.ChannelNames[self.module.settings.channel_id.value]}")
-        self.spec_plot.set_label(nsf_plots.NSFChart.Axis.bottom, "Frq")
-        self.spec_plot.set_unit(nsf_plots.NSFChart.Axis.bottom, "Hz")
-        self.spec_plot.set_label(nsf_plots.NSFChart.Axis.left, "Amplitude")
-        self.spec_plot.set_unit(nsf_plots.NSFChart.Axis.left, "")  
+        self.spec_plot.set_title(f"Spectrum of - {channel_name}")
+        self.spec_plot.set_label(nsf.gui.NSFChart.Axis.bottom, "Frq")
+        self.spec_plot.set_unit(nsf.gui.NSFChart.Axis.bottom, "Hz")
+        self.spec_plot.set_label(nsf.gui.NSFChart.Axis.left, "Amplitude")
+        self.spec_plot.set_unit(nsf.gui.NSFChart.Axis.left, "")  
         self.spec_plot.clear_plots()
 
     def on_button_start_stop_clicked(self):
@@ -254,8 +256,8 @@ class ScanScreen(module_base.ModuleScreen):
             calc_power_spec = self.module.settings.show_power_spec.value
             compress_spec = self.module.settings.show_compress_spec.value
             samplefrq = current_data.stream.get_stream_length()/self.module.settings.time_per_line.value
-            spec = sci_math.calc_fft(current_data.stream.get_channel(0), samplerate=samplefrq, powerspectrum=calc_power_spec, compress=compress_spec)
-            found, peak_x ,peak_y = sci_math.find_highest_peak(spec)
+            spec = nsf.sci_math.calc_fft(current_data.stream.get_channel(0), samplerate=samplefrq, powerspectrum=calc_power_spec, compress=compress_spec)
+            found, peak_x ,peak_y = nsf.sci_math.find_highest_peak(spec)
             if found:
                 self.spec_plot.set_marker(peak_x, peak_y)
                 self.tableResults.set_value(ResultTableID.Marker_X, peak_x, spec.get_stream_unit())
@@ -265,7 +267,7 @@ class ScanScreen(module_base.ModuleScreen):
                 self.tableResults.clear_value(ResultTableID.Marker_X)
                 self.tableResults.clear_value(ResultTableID.Marker_Y)
             
-            noise_floor = sci_math.get_noise_floor(spec)
+            noise_floor = nsf.sci_math.get_noise_floor(spec)
             self.spec_plot.plot_stream(spec)
             self.spec_plot.plot_data(y=[noise_floor for i in range(spec.get_stream_length())], x=spec.get_stream_range().value, layer_index=1)
             self.tableResults.set_value(ResultTableID.Noise_Floor, noise_floor, spec.get_channel(0).unit)
