@@ -30,8 +30,3 @@ class DemoResults():
 class PlotStyleID(enum.IntEnum):
     PlotSin = 0,
     PlotCos = 1,
-
-PlotStyleNames = [
-    'Sin-Plot', 
-    'Cos-Plot'
-]
