@@ -1,9 +1,8 @@
 # studio_scripting_demo client.py
 
-import nanosurf
-import nanosurf.lib.datatypes.sci_val as sci_val
+import nanosurf as nsf
 
-studio = nanosurf.Studio()
+studio = nsf.Studio()
 if studio.connect():
     print(f"Available sessions: {studio.main.session.list()}")
     print(f"Connected with session = '{studio.session_id}'")
@@ -30,9 +29,12 @@ if studio.connect():
         print(mode)
 
     # converting a property to SciVal
-    scan_range = sci_val.SciVal(imaging.property.scan_range_fast_axis)
+    scan_range_fast_axis = imaging.property.scan_range_fast_axis
+    scan_range = nsf.sci_val.SciVal(imaging.property.scan_range_fast_axis)
     print(f"Fast scan range converted to SciVal is {scan_range}")
-    print(f"But also this give the same result: {imaging.property.scan_range_fast_axis}")
+    print(f"This give the same result: {imaging.property.scan_range_fast_axis.value}")
+    print(f"And also this give the same result: {nsf.sci_val.convert.to_string(scan_range_fast_axis.value,scan_range_fast_axis.unit)}")
+    print(f"And this give the same value but not so nicely formatted: {scan_range_fast_axis.value}{scan_range_fast_axis.unit}")
 
     studio.disconnect()
 else:
