@@ -1,5 +1,5 @@
 
-""" applicationwide info box
+""" application wide info box
 Copyright Nanosurf AG 2021
 License - MIT
 """
@@ -39,3 +39,6 @@ class InfoBox(QtWidgets.QWidget):
 
     def _on_close_button_clicked(self):
         self.setHidden(True)
+
+class NSFInfoBox(InfoBox):
+    pass
