@@ -15,7 +15,8 @@ from PySide2.QtCore import Qt, QTimer, Signal
 
 import nanosurf.lib.datatypes.sci_val as sci_val
 import nanosurf.lib.datatypes.sci_val.unit_prefix as up
-import nanosurf.lib.datatypes.sci_val.convert as convert
+from nanosurf.lib.gui.nsf_widgets_common import g_nsf_label_widget_content_margins, g_nsf_label_widget_spacing
+
 
 class StepMode(enum.IntEnum):
     rel_1st_digi = 0, # increment relative the first significant digit 123.45 -> 223.45
@@ -618,6 +619,8 @@ class NSFSciEdit(QtWidgets.QWidget):
     
     def _setup_widgets(self, label_str: str):
         layout = QtWidgets.QVBoxLayout()
+        layout.setContentsMargins(*g_nsf_label_widget_content_margins)
+        layout.setSpacing(g_nsf_label_widget_spacing)        
         self._label = QtWidgets.QLabel()
         self._label.setText(label_str)
         self._label.setSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
