@@ -1,4 +1,4 @@
-"""Package for scripting the Nansurf control software.
+"""Package for scripting the Nanosurf control software.
 Copyright (C) Nanosurf AG - All Rights Reserved (2021)
 License - MIT"""
 
@@ -6,7 +6,7 @@ import time
 import logging
 import enum
 import typing
-import nanosurf.lib.spm as spm
+import nanosurf.lib.spm.com_proxy as spm
 
 class MotorID():
     """ Defines the identification parameters of a direct motor control motor. 
