@@ -325,7 +325,30 @@ class InputSource(enum.Enum):
     AxisInZ = enum.auto(),
     MainLockIn_Amplitude = enum.auto(),
     MainPLL_FreqShift = enum.auto(),
-    ZControllerOut = enum.auto()
+    ZControllerOut = enum.auto(),
+    InDetectorSum = enum.auto(),
+    In6 = enum.auto(),
+    CtrlX_Out = enum.auto(),
+    CtrlY_Out = enum.auto(),
+    CtrlW_Out = enum.auto(),
+    CtrlUser1_Out = enum.auto(),
+    CtrlUser2_Out = enum.auto(),
+    Analyzer1_CtrlDeltaF = enum.auto(),
+    Analyzer1_CtrlAmplitude = enum.auto(),
+    Analyzer1_Phase = enum.auto(),
+    Analyzer1_Amplitude = enum.auto(),
+    Analyzer1_X = enum.auto(),
+    Analyzer1_Y = enum.auto(),
+    # Selections would make sense if the sweep could use another signal analyzer than number 2:
+    # Analyzer2_CtrlDeltaF = enum.auto(),
+    # Analyzer2_CtrlAmplitude = enum.auto(),
+    # Analyzer2_Phase = enum.auto(),
+    # Analyzer2_Amplitude = enum.auto(),
+    # Analyzer2_X = enum.auto(),
+    # Analyzer2_Y = enum.auto(),
+    Ort_Baseline = enum.auto(),
+    Ort_AmplitudeReduction = enum.auto(),
+    Ort_Excitation = enum.auto(),
 
 class InputRanges(enum.Enum):
     Full = enum.auto(),
@@ -389,7 +412,30 @@ class FrequencySweep():
         InputSource.AxisInZ : "Axis In Z",
         InputSource.MainLockIn_Amplitude : "Main Lock-In Amplitude",
         InputSource.MainPLL_FreqShift : "Main PLL Frequency Shift",
-        InputSource.ZControllerOut : "Z-Controller Out"
+        InputSource.ZControllerOut : "Z-Controller Out",
+        InputSource.InDetectorSum : "Detector Sum",
+        InputSource.In6 : "Interface Aux Input",
+        InputSource.CtrlX_Out : "X-Controller Out",
+        InputSource.CtrlY_Out : "Y-Controller Out",
+        InputSource.CtrlW_Out : "W-Controller Out",
+        InputSource.CtrlUser1_Out : "Controller User 1 Out",
+        InputSource.CtrlUser2_Out : "Controller User 2 Out",
+        InputSource.Analyzer1_CtrlDeltaF : "Analyzer 1 Ctrl. Delta f",
+        InputSource.Analyzer1_CtrlAmplitude : "Analyzer 1 Ctrl. Amp.",
+        InputSource.Analyzer1_Amplitude : "Analyzer 1 Amplitude",
+        InputSource.Analyzer1_Phase : "Analyzer 1 Phase",
+        InputSource.Analyzer1_X : "Analyzer 1 X",
+        InputSource.Analyzer1_Y : "Analyzer 1 Y",
+        # Selections would make sense if the sweep could use another signal analyzer than number 2:
+        # InputSource.Analyzer2_CtrlDeltaF : "Analyzer 2 Ctrl. Delta f",
+        # InputSource.Analyzer2_CtrlAmplitude : "Analyzer 2 Ctrl. Amp.",
+        # InputSource.Analyzer2_Phase : "Analyzer 2 Phase",
+        # InputSource.Analyzer2_Amplitude : "Analyzer 2 Amplitude",
+        # InputSource.Analyzer2_X : "Analyzer 2 X",
+        # InputSource.Analyzer2_Y : "Analyzer 2 Y",
+        InputSource.Ort_Baseline : "WaveMode Baseline",
+        InputSource.Ort_AmplitudeReduction : "WaveMode Amplitude Reduction",
+        InputSource.Ort_Excitation : "WaveMode Excitation",
     }
 
     bandwidths_names = {
@@ -467,6 +513,29 @@ class FrequencySweep():
             InputSource.MainLockIn_Amplitude: self._analyzer.Input.Analyzer1_Amplitude,
             InputSource.MainPLL_FreqShift: self._analyzer.Input.Analyzer1_CtrlDeltaF,
             InputSource.ZControllerOut: self._analyzer.Input.CtrlZ_Out,
+            InputSource.InDetectorSum : self._analyzer.Input.self._analyzer.Input.InDetectorSum,
+            InputSource.In6 : self._analyzer.Input.In6,
+            InputSource.CtrlX_Out : self._analyzer.Input.CtrlX_Out,
+            InputSource.CtrlY_Out : self._analyzer.Input.CtrlY_Out,
+            InputSource.CtrlW_Out : self._analyzer.Input.CtrlW_Out,
+            InputSource.CtrlUser1_Out : self._analyzer.Input.CtrlUser1_Out,
+            InputSource.CtrlUser2_Out : self._analyzer.Input.CtrlUser2_Out,
+            InputSource.Analyzer1_CtrlDeltaF : self._analyzer.Input.Analyzer1_CtrlDeltaF,
+            InputSource.Analyzer1_CtrlAmplitude : self._analyzer.Input.Analyzer1_CtrlAmplitude,
+            InputSource.Analyzer1_Amplitude : self._analyzer.Input.Analyzer1_Amplitude,
+            InputSource.Analyzer1_Phase : self._analyzer.Input.Analyzer1_Phase,
+            InputSource.Analyzer1_X : self._analyzer.Input.Analyzer1_X,
+            InputSource.Analyzer1_Y : self._analyzer.Input.Analyzer1_Y,
+            # Selections would make sense if the sweep could use another signal analyzer than number 2:
+            # InputSource.Analyzer2_CtrlDeltaF : self._analyzer.Input.Analyzer2_CtrlDeltaF,
+            # InputSource.Analyzer2_CtrlAmplitude : self._analyzer.Input.Analyzer2_CtrlAmplitude,
+            # InputSource.Analyzer2_Phase : self._analyzer.Input.Analyzer2_Phase,
+            # InputSource.Analyzer2_Amplitude : self._analyzer.Input.Analyzer2_Amplitude,
+            # InputSource.Analyzer2_X : self._analyzer.Input.Analyzer2_X,
+            # InputSource.Analyzer2_Y : self._analyzer.Input.Analyzer2_Y,
+            InputSource.Ort_Baseline : self._analyzer.Input.Ort_Baseline,
+            InputSource.Ort_AmplitudeReduction : self._analyzer.Input.Ort_AmplitudeReduction,
+            InputSource.Ort_Excitation : self._analyzer.Input.Ort_Excitation,
         }
 
         self.input_range_to_gain_map: dict[InputRanges, float] = {
